# Load packages
library(here)
library(cowplot)
library(tidyverse)
library(scales)
library(plotrix)



# source functions
source(here("00_helpers.R"))
source(here("01_model.R"))
source(here("02_wrapper.R"))
source(here("03_default_parameters.R"))

cbbPalette <- c("#000000", "#E69F00", "#56B4E9", "#009E73", "#F0E442", "#0072B2", "#D55E00", "#CC79A7")

#### Running simulations #######################################################
#
# To run simulations for many combinations of parameters, we use the 
# model wrapper function (wrapper.R). It takes as input all of the parameters
# passed to the model, as well as the desired variable (X_vec is the default).
#
################################################################################

# For loop iterating across all values of L - all other parameters are fixed

####################################################################
####    SCENARIO 0 - FISHERY SHORT TERM PROFIT MAXIMIZATION     #### 
####################################################################

for (L in L_range){
  
  run <- wrapper0(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 mu = mu,
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 0
best_results_scenario_0 <- best_results




###############################################
####    SCENARIO 1 - CONTROL (OA + MEY)    #### 
###############################################

for (L in L_range){
  
  run <- wrapper1(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 mu = mu,
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 1
best_results_scenario_1 <- best_results




########################################
####    SCENARIO 2 - FISH PRICE     #### 
########################################

for (L in L_range){
  
  run <- wrapper2(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 pL = pL,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 mu = mu,
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 2
best_results_scenario_2 <- best_results



##############################################
####    SCENARIO 3  -  DETECTION SPEED    #### 
##############################################

for(L in L_range){
  
  run <- wrapper3(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 muL = muL,
                 muFPA = muFPA, 
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 3
best_results_scenario_3 <- best_results




##########################################
####    SCENARIO 4  -  ACCESS FEE     #### 
##########################################

for (L in L_range){
  
  run <- wrapper4(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 mu = mu,
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 4
best_results_scenario_4 <- best_results




#################################################
####    SCENARIO 5  -  COMBINED SCENARIOS    #### 
#################################################

for(L in L_range){
  
  run <- wrapper5(chi = chi, 
                 r = r,
                 K = K,
                 X0 = X0,
                 s = s,
                 D = D,
                 p = p,
                 pL = pL,
                 q = q,
                 c = c,
                 beta = beta,
                 L = L,
                 alpha = alpha,
                 muL = muL,
                 muFPA = muFPA, 
                 w = w,
                 years = years,
                 want = "All",
                 b = b) %>% 
    mutate(X_rel = X_r_vec / X_f_vec,
           L = L)
  
  if(L == L_range[1]){
    best_results <- run
    
  }else{
    best_results <- rbind(best_results, run)
  }
  
}


## Exact values for maximum biomass and optimal area of lease area 
results <- filter(best_results, X_vec == max(X_vec)) 
Max_biom <- results$X_vec/K
Max_biom # Maximum biomass value
L_opt_size <- results$L
L_opt_size # Size of the optimal lease area

# Result table - Scenario 5
best_results_scenario_5 <- best_results





######################################################################
## FIGURES -- L vs B and L vs R_tot for scenarios comparison 

### ---------------------------------------------------------------------------
# Combined Plot 1 // L vs B for default parameters // Scenario 0 vs Scenario 1
### ---------------------------------------------------------------------------

optimal_B_for_L_plot_scenario_0_vs_1 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = X_vec / K)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4",
             size = 1) +
  geom_line(data = best_results_scenario_0, color = "black", size = 3)+
  geom_vline(data = filter(best_results_scenario_0, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "black",
             size = 1)+
  
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_1,X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.65, y = 0.71, colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Optimal EFAC proportion 
=", round(filter(best_results_scenario_1,X_vec == max(X_vec))$L,2) ),
           x =  0.65, y = 0.69,colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_0, X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.6, y = 0.80, colour= "black", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal CFA proportion 
=", round(filter(best_results_scenario_0,X_vec == max(X_vec))$L,2) ),
           x = 0.6 , y = 0.78, colour= "black", fontface ="bold", size = 5)+

  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  
  labs(x = "Proportion of Lease area",
       y = X_legend, size = 13)


optimal_B_for_L_plot_scenario_0_vs_1



### ----------------------------------------------------------------------------------
# Combined Plot 1 bis // L vs R_tot for default parameters // Scenario 0 vs Scenario 1
### ----------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_0_vs_1 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4",
             size = 1 ) +
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 1790000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  geom_line(data = best_results_scenario_0, color = "black", size = 3)+
  geom_vline(data = filter(best_results_scenario_0, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "black",
             size = 1)+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 132440039),
             linetype = "longdash",
             color = "black",
             size = 1) +
  
  
  annotate("text",label= paste0("Corresponding total profit 
= 1 790 000 $"), 
           x = 0.65, y = 9.1e+07, colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Optimal EFAC proportion 
=", round(filter(best_results_scenario_1,X_vec == max(X_vec))$L,2) ),
           x =  0.65, y = 7e+07,colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Corresponding total profit 
= 132 440 039 $ "), 
           x = 0.65, y = 1.96e+08, colour= "black", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal CFA proportion 
=", round(filter(best_results_scenario_0,X_vec == max(X_vec))$L,2) ),
           x = 0.65 , y = 1.75e+08, colour= "black", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0, 2e+08))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),  
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "Proportion of Lease area",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_0_vs_1



### ----------------------------------------------------------------------------
# Combined Plot 2 // L vs B for default parameters // Scenario 1 vs Scenario 2 
### ----------------------------------------------------------------------------

optimal_B_for_L_plot_scenario_1_vs_2 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = X_vec / K)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  
  geom_line(data = best_results_scenario_2, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_2, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_1,X_vec == max(X_vec))$X_vec/K,2)),
         x = 0.7, y = 0.78, colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Control EFAC proportion =", round(filter(best_results_scenario_1,X_vec == max(X_vec))$L,2) ),
         x =  0.7, y = 0.77,colour= "blue4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_2, X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.7, y = 0.81, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion =", round(filter(best_results_scenario_2,X_vec == max(X_vec))$L,2) ),
           x = 0.7 , y = 0.8, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend, size = 13)


optimal_B_for_L_plot_scenario_1_vs_2


### -------------------------------------------------------------------------------------
# Combined Plot 2 bis //  L vs R_tot for default parameters // Scenario 1 vs Scenario 2 
### -------------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_2 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 1790000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  geom_line(data = best_results_scenario_2, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_2, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 2100000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  annotate("text",label= paste0("Corresponding total profit
  = 1 790 000 $"), 
           x = 0.82, y = 8.5e+07, colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Control EFAC proportion = ", round(filter(best_results_scenario_1,X_vec == max(X_vec))$L,2) ),
           x =  0.82, y = 1e+08,colour= "blue4", fontface ="bold", size = 5) +
  annotate("text",label= paste0("Corresponding total profit
  = 2 000 000 $"), 
           x = 0.86, y = 1.4e+08, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion 
=", round(filter(best_results_scenario_2,X_vec == max(X_vec))$L,2) ),
           x = 0.86 , y = 1.6e+08, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  scale_y_continuous(limits = c(0,2e+08))+
  # scale_x_continuous(limits = c(0,0.5))+
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_1_vs_2


### ---------------------------------------------------------------------------------------
# Combined Plot 2 bis ZOOM // L vs R_tot for default parameters // Scenario 1 vs Scenario 2
### ----------------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_2_ZOOM <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "longdash",
             color = "blue4") +
  geom_hline(data = filter(best_results_scenario_1),
            aes(yintercept = 1790000),
            linetype = "longdash",
            color = "blue4",
            size = 1) +
  
  geom_line(data = best_results_scenario_2, color = "chartreuse4",size = 3)+
  geom_vline(data = filter(best_results_scenario_2, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "longdash",
             color = "chartreuse4")+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 2100000),
             linetype = "longdash",
             color = "chartreuse4",
             size = 1) +
  
  annotate("text",label= paste0("Total profit for 
optimal EFAC
= 1 790 000 $"), 
          x = 0.32, y = 3e+06, colour= "blue4", fontface ="bold", size = 5) +
  
  annotate("text",label= paste0("Total profit for 
optimal EFAC
= 2 100 000 $"), 
           x = 0.10, y = 3e+06, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  # guides(fill = guide_legend(title ="Scenario"))+
         #size = guide_legend(title = expression(X[M] / X[`F`]))) +
  scale_y_continuous(limits = c(0,4.5e+06), breaks = c(0,2e+06, 4e+06))+
  scale_x_continuous(limits = c(0,0.5),breaks = c(0,0.25,0.5))+
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13))+
  labs(x = "",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_1_vs_2_ZOOM 



### ---------------------------------------------------------------------------
# Combined Plot 3 // L vs B for default parameters // Scenario 1 vs Scenario 3 
### ---------------------------------------------------------------------------

optimal_B_for_L_plot_scenario_1_vs_3 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = X_vec / K)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_3, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_3, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
  
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_3, X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.75, y = 0.79, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion =", round(filter(best_results_scenario_3,X_vec == max(X_vec))$L,2) ),
           x = 0.75 , y = 0.78, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend, size = 13)


optimal_B_for_L_plot_scenario_1_vs_3


### ----------------------------------------------------------------------------------
# Combined Plot 3 bis // L vs R_tot for default parameters // Scenario 1 vs Scenario 3
### ----------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_3 <- 
  ggplot(data = best_results_scenario_1, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_3, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_3, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
 
  annotate("text",label= paste0("Corresponding total profit = 3 760 000 $"), 
           x = 0.75, y = 9e+07, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion =", round(filter(best_results_scenario_3,X_vec == max(X_vec))$L,2) ),
           x = 0.75 , y = 1e+08, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0, 2e+08))+
  # scale_x_continuous(limits = c(0, 0.5))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend_R_tot)


optimal_R_tot_for_L_plot_scenario_1_vs_3

### ----------------------------------------------------------------------------------
# Combined Plot 3 bis ZOOM// Temoin vs COUTS // L vs R_tot for default parameters 
### ----------------------------------------------------------------------------------


optimal_R_tot_for_L_plot_scenario_1_vs_3_ZOOM <- 
  ggplot(data = best_results_scenario_1, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4",size  = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
   geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 1790000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  geom_line(data = best_results_scenario_3, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_3, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 3790000),
             linetype = "longdash",
             color = "chartreuse4",
             size = 1) +
  
 
  annotate("text",label= paste0("Total profit for optimal EFAC
= 3 760 000 $"), 
           x = 0.15, y = 3e+06, colour= "chartreuse4", fontface ="bold", size = 5)+

  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0,4.5e+06), breaks = c(0,2e+06, 4e+06))+
  scale_x_continuous(limits = c(0,0.5),breaks = c(0,0.25,0.5))+
  # guides(fill = guide_legend(title ="Scenario"),
        #  size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_1_vs_3_ZOOM 



### ----------------------------------------------------------------------------
# Combined Plot 4 //  L vs B for default parameters // Scenario 1 vs Scenario 4
### ----------------------------------------------------------------------------

optimal_B_for_L_plot_scenario_1_vs_4 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = X_vec / K)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_4, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_4, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
  
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_4, X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.75, y = 0.79, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion =", round(filter(best_results_scenario_4,X_vec == max(X_vec))$L,2) ),
           x = 0.75 , y = 0.78, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend, size = 13)


optimal_B_for_L_plot_scenario_1_vs_4


### ----------------------------------------------------------------------------------
# Combined Plot 4 bis //  L vs R_tot for default parameters  // Scenario 1 vs Scenario 4
### ----------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenatio_1_vs_4 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_4, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_4, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
  
  annotate("text",label= paste0("Corresponding total profit = 1 210 000 $ "), 
           x = 0.68, y = 9e+07, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion =", round(filter(best_results_scenario_4,X_vec == max(X_vec))$L,2) ),
           x = 0.68 , y = 1e+08, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0, 2e+08))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend_R_tot)


optimal_R_tot_for_L_plot_scenatio_1_vs_4


### -----------------------------------------------------------------------------------------
# Combined Plot 4 bis ZOOM // L vs R_tot for default parameters //  Scenario 1 vs Scenario 4
### -----------------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_4_ZOOM <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size=3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 1790000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  geom_line(data = best_results_scenario_4, color = "chartreuse4",size = 3)+
  geom_vline(data = filter(best_results_scenario_4, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 698384),
             linetype = "longdash",
             color = "chartreuse4",
             size = 1) +
  
 
  annotate("text",label= paste0("Total profit for optimal EFAC 
= 698 384 $"), 
           x = 0.15, y = 3e+06, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0,4.5e+06), breaks = c(0,2e+06, 4e+06))+
  scale_x_continuous(limits = c(0,0.5),breaks = c(0,0.25,0.5))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_1_vs_4_ZOOM



### ---------------------------------------------------------------------------
# Combined Plot 5 // L vs B for default parameters // Scenario 1 vs Scenario 5 
### ---------------------------------------------------------------------------

optimal_B_for_L_plot_scenario_1_vs_5 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = X_vec / K)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_5, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_5, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
 
  annotate("text",label= paste0("Max X/K =",round(filter(best_results_scenario_5, X_vec == max(X_vec))$X_vec/K,2)),
           x = 0.75, y = 0.81, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC proportion=", round(filter(best_results_scenario_5,X_vec == max(X_vec))$L,2) ),
           x = 0.75 , y = 0.8, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "Proportion of EFAC area",
       y = X_legend, size = 13)


optimal_B_for_L_plot_scenario_1_vs_5


### ----------------------------------------------------------------------------------
# Combined Plot 5 bis // L vs R_tot for default parameters // Scenario 1 vs Scenario 5 
### ----------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_5 <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_line(data = best_results_scenario_5, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_5, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  
 
  annotate("text",label= paste0("Corresponding total profit
= 2 450 000 $"), 
           x = 0.85, y = 8e+07, colour= "chartreuse4", fontface ="bold", size = 5)+
  annotate("text",label= paste0("Optimal EFAC 
proportion =", round(filter(best_results_scenario_5,X_vec == max(X_vec))$L,2) ),
           x = 0.87 , y = 1.1e+08, colour= "chartreuse4", fontface = "bold", size = 5, )+
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0, 2e+08))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "Proportion of EFAC area",
       y = X_legend_R_tot)


optimal_R_tot_for_L_plot_scenario_1_vs_5


### ----------------------------------------------------------------------------------------
# Combined Plot 5 bis ZOOM //  L vs R_tot for default parameters // Scenario 1 vs Scenario 5 
### -----------------------------------------------------------------------------------------

optimal_R_tot_for_L_plot_scenario_1_vs_5_ZOOM <- 
  ggplot(data = NULL, mapping = aes(x = L, y = R_tot_vec)) +
  
  geom_line(data = best_results_scenario_1, color = "blue4", size = 3) +
  geom_vline(data = filter(best_results_scenario_1, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "blue4") +
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 1790000),
             linetype = "longdash",
             color = "blue4",
             size = 1) +
  
  geom_line(data = best_results_scenario_5, color = "chartreuse4", size = 3)+
  geom_vline(data = filter(best_results_scenario_5, X_vec == max(X_vec)),
             aes(xintercept = L),
             linetype = "dashed",
             color = "chartreuse4")+
  geom_hline(data = filter(best_results_scenario_1),
             aes(yintercept = 2450000),
             linetype = "longdash",
             color = "chartreuse4",
             size = 1) +
 
  annotate("text",label= paste0("Total profit for 
optimal EFAC
= 2 450 000$"), 
           x = 0.10, y = 3.5e+06, colour= "chartreuse4", fontface ="bold", size = 5)+
  
  scale_fill_viridis_c() +
  scale_y_continuous(limits = c(0,4.5e+06), breaks = c(0,2e+06, 4e+06))+
  scale_x_continuous(limits = c(0,0.5),breaks = c(0,0.25,0.5))+
  guides(fill = guide_legend(title ="Scenario"),
         size = guide_legend(title = expression(X[M] / X[`F`]))) +
  plot_theme() +
  theme(legend.position = c(0.01, 1),
        legend.justification = c(0, 1),
        axis.title.x = element_text( size = 21),
        axis.title.y = element_text( size = 21),
        axis.text =element_text(size=13)) +
  labs(x = "Proportion of EFAC area",
       y = X_legend_R_tot, size = 13)


optimal_R_tot_for_L_plot_scenario_1_vs_5_ZOOM



######################################################################
# FINAL FIGURES - MODEL BIOMASS AND PROFIT ACCORDING TO LEASE AREA 

# 2 COLUMNS  FIGURES
# 1 column : Biomass // 1 column : Profit (zoom plot)

# B and R_tot scenario 0 and 1 
FIG_B_and_R_tot_scenario_0_vs_1 <- plot_grid(optimal_B_for_L_plot_scenario_0_vs_1,
                                             optimal_R_tot_for_L_plot_scenario_0_vs_1,
                                             ncol = 2,
                                             rel_heights = c(1,1),
                                             labels = c("A", "B"), 
                                             label_size = 20)

FIG_B_and_R_tot_scenario_0_vs_1 

# Final figure
FINAL_fig <- plot_grid(optimal_B_for_L_plot_scenario_1_vs_2,
                        optimal_R_tot_for_L_plot_scenario_1_vs_2_ZOOM,
                        optimal_B_for_L_plot_scenario_1_vs_3, 
                        optimal_R_tot_for_L_plot_scenario_1_vs_3_ZOOM,
                        optimal_B_for_L_plot_scenario_1_vs_4,
                        optimal_R_tot_for_L_plot_scenario_1_vs_4_ZOOM,
                        optimal_B_for_L_plot_scenario_1_vs_5,
                        optimal_R_tot_for_L_plot_scenario_1_vs_5_ZOOM,
                        ncol = 2,
                        rel_heights = c(1,1),
                        labels = c("A", "B","C", "D","E" ,"F","G", "H","I","J"),
                        label_size = 20)




# 3 COLUMNS FIGURES
# 1 column : Biomass // 1 column : Profit // 1 column : Profit (zoom)

# Separate scenarios

FIG_B_and_R_tot_scenario_1_vs_2 <- plot_grid(optimal_B_for_L_plot_scenario_1_vs_2, 
                                             optimal_R_tot_for_L_plot_scenario_1_vs_2,
                                             optimal_R_tot_for_L_plot_scenario_1_vs_2_ZOOM,
                                             ncol = 3,
                                             rel_heights = c(1,2),
                                             labels = c("C", "D"),
                                             label_size = 20)

FIG_B_and_R_tot_scenario_1_vs_3  <-plot_grid(optimal_B_for_L_plot_scenario_1_vs_3, 
                                             optimal_R_tot_for_L_plot_scenario_1_vs_3,
                                             optimal_R_tot_for_L_plot_scenario_1_vs_3_ZOOM,
                                             ncol = 3,
                                             rel_heights = c(1,1),
                                             labels = c("E" ,"F"),
                                             label_size = 20)

FIG_B_and_R_tot_scenario_1_vs_4  <- plot_grid(optimal_B_for_L_plot_scenario_1_vs_4,
                                              optimal_R_tot_for_L_plot_scenatio_1_vs_4,
                                              optimal_R_tot_for_L_plot_scenario_1_vs_4_ZOOM,
                                              ncol = 3,
                                              rel_heights = c(1,1),
                                              labels = c("G", "H"),
                                              label_size = 20)

FIG_B_and_R_tot_scenario_1_vs_5 <- plot_grid( optimal_B_for_L_plot_scenario_1_vs_5,
                                              optimal_R_tot_for_L_plot_scenario_1_vs_5,
                                              optimal_R_tot_for_L_plot_scenario_1_vs_5_ZOOM,
                                              ncol = 3,
                                              rel_heights = c(1,1),
                                              labels = c("I", "J"),
                                              label_size = 20)


FIG_B_and_R_tot_scenario_1_vs_2
FIG_B_and_R_tot_scenario_1_vs_3
FIG_B_and_R_tot_scenario_1_vs_4
FIG_B_and_R_tot_scenario_1_vs_5


# Combined scenarios

FINAL_fig_table_3col <- plot_grid(optimal_B_for_L_plot_scenario_1_vs_2, 
                                     optimal_R_tot_for_L_plot_scenario_1_vs_2,
                                     optimal_R_tot_for_L_plot_scenario_1_vs_2_ZOOM,
                                     optimal_B_for_L_plot_scenario_1_vs_3, 
                                     optimal_R_tot_for_L_plot_scenario_1_vs_3,
                                     optimal_R_tot_for_L_plot_scenario_1_vs_3_ZOOM,
                                     optimal_B_for_L_plot_scenario_1_vs_4,
                                     optimal_R_tot_for_L_plot_scenatio_1_vs_4,
                                     optimal_R_tot_for_L_plot_scenario_1_vs_4_ZOOM,
                                     optimal_B_for_L_plot_scenario_1_vs_5,
                                     optimal_R_tot_for_L_plot_scenario_1_vs_5,
                                     optimal_R_tot_for_L_plot_scenario_1_vs_5_ZOOM,
                                     ncol = 3,
                                     rel_heights = c(1,1),
                                     labels = c("A", "B","C", "D","E" ,"F","G", "H", "I", "J","K","L"),
                                     label_size = 20)


## SAVING FIGURES

# B and R_tot scenario 0 and 1 
lazy_ggsave(plot = FIG_B_and_R_tot_scenario_0_vs_1 ,
            filename = "FIG_B_and_R_tot_scenario_0_vs_1",
            width = 35, height = 15)

# Final figure 
lazy_ggsave(plot = FINAL_fig,
            filename = "FINAL_fig",
            width = 40, height = 70)


# Separate scenarios 
lazy_ggsave(plot = FIG_B_and_R_tot_scenario_1_vs_2,
            filename = "FIG_B_and_R_tot_scenario_1_vs_2",
            width = 45, height = 20)

lazy_ggsave(plot = FIG_B_and_R_tot_scenario_1_vs_3,
            filename = "FIG_B_and_R_tot_scenario_1_vs_3",
            width = 45, height = 20)

lazy_ggsave(plot = FIG_B_and_R_tot_scenario_1_vs_4,
            filename = "FIG_B_and_R_tot_scenario_1_vs_4",
            width = 45, height = 20)

lazy_ggsave(plot = FIG_B_and_R_tot_scenario_1_vs_5,
            filename = "FIG_B_and_R_tot_scenario_1_vs_5",
            width = 35, height = 15)

# Combined scenarios
lazy_ggsave(plot = FINAL_fig_table_3col,
            filename = "FINAL_fig_table_3col",
            width = 60, height = 70)







##########################################################
##                 Sensibility analyses                 ##
##########################################################

### ------------------------------------------------------
# Table 1: Information of optimal L for default parameters (chi is fixed)
### ------------------------------------------------------

#max_conservation_benefit <- best_results %>%
  #dplyr::filter(L == 0 | X_vec == max(X_vec)) %>%
  #dplyr::select(L, X = X_vec, )

#### UPDATE GEOM DEFAULTS FOR SUBPLOTS

update_geom_defaults(geom = "point", new = list(size = 1.5))


### --------------------------------------------------------------------
# Plot 1: L vs B for four different dispersal scenarios (chi is fixed)
### --------------------------------------------------------------------

L_X_and_dispersal <- 
  expand_grid(L_try = L_range,
              self_rec = self_rec_range) %>% 
  mutate(D_try = map(self_rec, make_D)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  D = D_try),
                        .f = wrapper1,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w,
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(X_rel = X_r_vec / X_f_vec,
         self_rec = factor(self_rec, levels = sort(unique(self_rec)))) %>% 
  select(self_rec, L_try, X_vec, X_rel)


L_X_and_dispersal_plot <- 
  ggplot(data = L_X_and_dispersal,
         mapping = aes(x = L_try, y = X_vec / K, group = self_rec, color = self_rec)) +
  geom_line(size= 1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  scale_color_manual(values = cbbPalette,
                     labels = as.character(self_rec_range)) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 17),
        axis.title.y = element_text( size = 17)) +
  guides(color = guide_legend(title = bquote("Self-recruitment ("~d[`M,M`]~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  labs(x = "",
       y = "Equilibrium biomass (X / K)")

L_X_and_dispersal_plot

### --------------------------------------------------------------------------
# Plot 1 bis: L vs R_tot for four different dispersal scenarios (chi is fixed)
### --------------------------------------------------------------------------

L_R_tot_and_dispersal <- 
  expand_grid(L_try = L_range,
              self_rec = self_rec_range) %>% 
  mutate(D_try = map(self_rec, make_D)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  D = D_try),
                        .f = wrapper1,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w,
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(R_tot_vec,
         self_rec = factor(self_rec, levels = sort(unique(self_rec)))) %>% 
  select(self_rec, L_try, R_tot_vec)


L_R_tot_and_dispersal_plot <- 
  ggplot(data = L_R_tot_and_dispersal,
         mapping = aes(x = L_try, y = R_tot_vec, group = self_rec, color = self_rec)) +
  geom_line(size= 1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  scale_color_manual(values = cbbPalette,
                     labels = as.character(self_rec_range)) +
  
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 17),
        axis.title.y = element_text( size = 17)) +
  guides(color = guide_legend(title = bquote("Self-recruitment ("~d[`M,M`]~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  labs(x = "",
       y = "Equilibrium biomass (X / K)")
  
L_R_tot_and_dispersal_plot

### -----------------------------------------------------------
# Plot 2: L vs B for five different fish price (chi is fixed)
### -----------------------------------------------------------

L_X_and_p_fish_price <- expand_grid(L_try = L_range,
                         pL_try = (pL_range_multipliers*p)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  pL = pL_try),
                        .f = wrapper2,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        q = q,
                        p = p,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w, 
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(X_rel = X_r_vec / X_f_vec,
         pL_try = factor(pL_try, levels = sort(unique(pL_try)))) %>% 
  select(pL_try, L_try, X_vec, X_rel)

L_X_and_p_plot_fish_price <- 
  ggplot(data = L_X_and_p_fish_price,
         mapping = aes(x = L_try, y = X_vec / K, group = pL_try, color = pL_try)) +
  geom_line(size= 1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(pL_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 17),
        axis.title.y = element_text( size = 17)) +
  guides(color = guide_legend(title = bquote("Ecolabelled fish price ("~pL~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  labs(x = "",
       y = "Equilibrium biomass (X / K)")

L_X_and_p_plot_fish_price


### -------------------------------------------------------------------
# Plot 2 bis : L vs R_tot for five different fish price (chi is fixed)
### -------------------------------------------------------------------

L_R_tot_and_p_fish_price <- expand_grid(L_try = L_range,
                             pL_try = (pL_range_multipliers*p)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  pL = pL_try),
                        .f = wrapper2,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w, 
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(R_tot_vec,
         pL_try = as.factor(pL_try)) %>% 
  select(pL_try, L_try, R_tot_vec)

L_R_tot_and_p_plot_fish_price <- 
  ggplot(data = L_R_tot_and_p_fish_price,
         mapping = aes(x = L_try, y = R_tot_vec, group = pL_try, color = pL_try)) +
  geom_line(size=1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  
  # scale_y_continuous(limits = c(0,4e+06), breaks = c(0,2e+06, 4e+06))+
  # scale_x_continuous(limits = c(0,0.35),breaks = c(0,0.25,0.5))+
  
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(pL_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 17),
        axis.title.y = element_text( size = 17)) +
  guides(color = guide_legend(title = bquote("Ecolabelled fish price ("~pL~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  labs(x = "",
       y = X_legend_R_tot)

L_R_tot_and_p_plot_fish_price

### -------------------------------------------------
# Plot 3: L vs B for five different access fee (chi)
### -------------------------------------------------

L_X_and_chi <- expand_grid(L_try = L_range,
                           chi_try = (chi_range_multipliers*chi)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  chi = chi_try),
                        .f = wrapper1,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w, 
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(X_rel = X_r_vec / X_f_vec,
         chi_try = as.factor(chi_try)) %>% 
  select(chi_try, L_try, X_vec, X_rel)

L_X_and_chi_plot <- 
  ggplot(data = L_X_and_chi,
         mapping = aes(x = L_try, y = X_vec / K, group = chi_try, color = chi_try)) +
  geom_line(size= 1) +
  geom_point(size=3) +
  scale_fill_viridis_c() +
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(chi_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  guides(color = guide_legend(title = bquote("Access fee ("~chi~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  labs(x = "",
       y = "Equilibrium biomass (X / K)")

L_X_and_chi_plot


### ----------------------------------------------------------
# Plot 3 bis : L vs R_tot for five different access fee (chi)
### ----------------------------------------------------------

L_R_tot_and_chi <- expand_grid(L_try = L_range,
                               chi_try = (chi_range_multipliers*chi)) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  chi = chi_try),
                        .f = wrapper1,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        alpha = alpha,
                        mu = mu,
                        w = w, 
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(R_tot_vec,
         chi_try = as.factor(chi_try)) %>% 
  select(chi_try, L_try, R_tot_vec)

L_R_tot_and_chi_plot <- 
  ggplot(data = L_R_tot_and_chi,
         mapping = aes(x = L_try, y = R_tot_vec, group = chi_try, color = chi_try)) +
  geom_line(size=1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  
  # scale_y_continuous(limits = c(0,4e+06), breaks = c(0,2e+06, 4e+06))+
  # scale_x_continuous(limits = c(0,0.35),breaks = c(0,0.25,0.5))+
  
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(chi_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 17),
        axis.title.y = element_text( size = 17)) +
  guides(color = guide_legend(title = bquote("Access fee ("~chi~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 15),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  
  labs(x = "",
       y = X_legend_R_tot)

L_R_tot_and_chi_plot


### --------------------------------------------------------------------
# Plot 4: L vs B for five different enforcement costs (chi is optimized)
### --------------------------------------------------------------------

L_X_and_enforcement_costs <- expand_grid(L_try = L_range,
                                         alpha_try = alpha_range_multipliers*alpha) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  alpha = alpha_try),
                        .f = wrapper1,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        mu = mu,
                        w = w,
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(X_rel = X_r_vec / X_f_vec,
         alpha_try = factor(alpha_try, levels = sort(unique(alpha_try)))) %>% 
  select(alpha_try, L_try, X_vec, X_rel)


L_X_and_enforcement_costs_plot <- 
  ggplot(data = L_X_and_enforcement_costs,
         mapping = aes(x = L_try, y = X_vec / K, group = alpha_try, color = alpha_try)) +
  geom_line(size= 1) +
  geom_point(size= 3) +
  scale_fill_viridis_c() +
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(alpha_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  guides(fill = "none",
         size = "none",
         color = guide_legend(title = bquote("Enforcement costs ("~alpha~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+

  labs(x = "Proportion of EFAC area",
       y = X_legend)

L_X_and_enforcement_costs_plot


### -------------------------------------------------------------------------------
# Plot 4 bis : L vs R_tot for five different enforcement costs (chi is optimized)
### -------------------------------------------------------------------------------

L_R_tot_and_enforcement_costs <- expand_grid(L_try = L_range,
                                         alpha_try = alpha_range_multipliers*alpha) %>% 
  mutate(results = pmap(.l = list(L = L_try,
                                  alpha = alpha_try),
                        .f = wrapper1,
                        chi = chi,
                        r = r,
                        K = K,
                        X0 = X0,
                        s = s,
                        D = D,
                        p = p,
                        q = q,
                        c = c,
                        beta = beta,
                        mu = mu,
                        w = w,
                        years = years,
                        want = "All")) %>% 
  unnest(cols = results) %>% 
  mutate(R_tot_vec,
         alpha_try = factor(alpha_try, levels = sort(unique(alpha_try)))) %>% 
  select(alpha_try, L_try, R_tot_vec)


L_R_tot_and_enforcement_costs_plot <- 
  ggplot(data = L_R_tot_and_enforcement_costs,
         mapping = aes(x = L_try, y = R_tot_vec, group = alpha_try, color = alpha_try)) +
  geom_line(size= 1) +
  geom_point(size=3) +
  scale_fill_viridis_c() +
  
  # scale_y_continuous(limits = c(0,4e+06), breaks = c(0,2e+06, 4e+06))+
  # scale_x_continuous(limits = c(0,0.35),breaks = c(0,0.25,0.5))+
  
  scale_color_manual(values = cbbPalette,
                     labels = paste0(as.character(alpha_range_multipliers), "x")) +
  plot_theme() +
  theme(legend.position = "top",
        legend.text = element_text(size=15),
        legend.title = element_text(size = 18)) +
  guides(fill = "none",
         size = "none",
         color = guide_legend(title = bquote("Enforcement costs ("~alpha~")"),
                              title.position = "top",
                              title.hjust = 0.5)) +
  theme(legend.position = "top",
        axis.title.x = element_text( size = 18),
        axis.title.y = element_text( size = 18),
        axis.text =element_text(size=10))+
  
  labs(x = "Proportion of EFAC area",
       y = X_legend_R_tot)

L_R_tot_and_enforcement_costs_plot




######################################################
##   FINAL FIGURE -- Sensibility analyses

fig_sensibi_FINALE <- plot_grid(L_X_and_dispersal_plot,
                                L_R_tot_and_dispersal_plot,
                                L_X_and_p_plot_fish_price,
                                L_R_tot_and_p_plot_fish_price,
                                L_X_and_chi_plot,
                                L_R_tot_and_chi_plot,
                                L_X_and_enforcement_costs_plot,
                                L_R_tot_and_enforcement_costs_plot,
                                ncol = 2,
                                labels = c("A", "B", "C", "D", "E", "F", "G", "H"))
fig_sensibi_FINALE 

lazy_ggsave(plot = fig_sensibi_FINALE,
            filename = "figure_sensibi_FINALE",
            width = 25, height = 40) 

